# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "accelerator_type": "acceleratorType",
    "access_context_manager_custom_endpoint": "accessContextManagerCustomEndpoint",
    "access_token": "accessToken",
    "account_id": "accountId",
    "ack_deadline_seconds": "ackDeadlineSeconds",
    "additional_zones": "additionalZones",
    "addons_config": "addonsConfig",
    "address_type": "addressType",
    "admin_enabled": "adminEnabled",
    "admission_whitelist_patterns": "admissionWhitelistPatterns",
    "advertise_mode": "advertiseMode",
    "advertised_groups": "advertisedGroups",
    "advertised_ip_ranges": "advertisedIpRanges",
    "advertised_route_priority": "advertisedRoutePriority",
    "affinity_cookie_ttl_sec": "affinityCookieTtlSec",
    "all_ports": "allPorts",
    "allow_stopping_for_update": "allowStoppingForUpdate",
    "alternative_location_id": "alternativeLocationId",
    "alternative_name_server_config": "alternativeNameServerConfig",
    "app_engine_custom_endpoint": "appEngineCustomEndpoint",
    "app_engine_http_target": "appEngineHttpTarget",
    "app_id": "appId",
    "app_profile_id": "appProfileId",
    "archive_size_bytes": "archiveSizeBytes",
    "attached_disks": "attachedDisks",
    "attestation_authority": "attestationAuthority",
    "attestation_authority_note": "attestationAuthorityNote",
    "audit_log_configs": "auditLogConfigs",
    "auth_domain": "authDomain",
    "authenticator_groups_config": "authenticatorGroupsConfig",
    "authorized_network": "authorizedNetwork",
    "auto_create_network": "autoCreateNetwork",
    "auto_create_routes": "autoCreateRoutes",
    "auto_create_subnetworks": "autoCreateSubnetworks",
    "auto_healing_policies": "autoHealingPolicies",
    "autoscaling_policy": "autoscalingPolicy",
    "available_memory_mb": "availableMemoryMb",
    "backend_bucket": "backendBucket",
    "backend_service": "backendService",
    "backup_pool": "backupPool",
    "base_instance_name": "baseInstanceName",
    "basic_algorithm": "basicAlgorithm",
    "big_query_custom_endpoint": "bigQueryCustomEndpoint",
    "bigquery_data_transfer_custom_endpoint": "bigqueryDataTransferCustomEndpoint",
    "bigtable_custom_endpoint": "bigtableCustomEndpoint",
    "billing_account": "billingAccount",
    "billing_account_id": "billingAccountId",
    "binary_authorization_custom_endpoint": "binaryAuthorizationCustomEndpoint",
    "blacklist_patterns": "blacklistPatterns",
    "boolean_policy": "booleanPolicy",
    "boot_disk": "bootDisk",
    "bucket_name": "bucketName",
    "bucket_options": "bucketOptions",
    "bucket_policy_only": "bucketPolicyOnly",
    "cache_control": "cacheControl",
    "can_ip_forward": "canIpForward",
    "candidate_subnets": "candidateSubnets",
    "cdn_policy": "cdnPolicy",
    "cert_serial_number": "certSerialNumber",
    "certificate_id": "certificateId",
    "check_interval_sec": "checkIntervalSec",
    "cidr_block": "cidrBlock",
    "circuit_breakers": "circuitBreakers",
    "cloud_billing_custom_endpoint": "cloudBillingCustomEndpoint",
    "cloud_build_custom_endpoint": "cloudBuildCustomEndpoint",
    "cloud_function": "cloudFunction",
    "cloud_functions_custom_endpoint": "cloudFunctionsCustomEndpoint",
    "cloud_iot_custom_endpoint": "cloudIotCustomEndpoint",
    "cloud_router_ip_address": "cloudRouterIpAddress",
    "cloud_run_custom_endpoint": "cloudRunCustomEndpoint",
    "cloud_scheduler_custom_endpoint": "cloudSchedulerCustomEndpoint",
    "cluster_admission_rules": "clusterAdmissionRules",
    "cluster_autoscaling": "clusterAutoscaling",
    "cluster_config": "clusterConfig",
    "cluster_ipv4_cidr": "clusterIpv4Cidr",
    "code_bucket": "codeBucket",
    "column_families": "columnFamilies",
    "column_family": "columnFamily",
    "common_name": "commonName",
    "composer_custom_endpoint": "composerCustomEndpoint",
    "compute_beta_custom_endpoint": "computeBetaCustomEndpoint",
    "compute_custom_endpoint": "computeCustomEndpoint",
    "config_id": "configId",
    "connection_draining_timeout_sec": "connectionDrainingTimeoutSec",
    "connection_name": "connectionName",
    "consistent_hash": "consistentHash",
    "container_analysis_custom_endpoint": "containerAnalysisCustomEndpoint",
    "container_beta_custom_endpoint": "containerBetaCustomEndpoint",
    "container_custom_endpoint": "containerCustomEndpoint",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_language": "contentLanguage",
    "content_matchers": "contentMatchers",
    "content_type": "contentType",
    "cpu_platform": "cpuPlatform",
    "create_time": "createTime",
    "creation_record": "creationRecord",
    "creation_time": "creationTime",
    "creation_timestamp": "creationTimestamp",
    "crypto_key_id": "cryptoKeyId",
    "current_location_id": "currentLocationId",
    "custom_attributes": "customAttributes",
    "custom_features": "customFeatures",
    "custom_request_headers": "customRequestHeaders",
    "customer_router_ip_address": "customerRouterIpAddress",
    "data_refresh_window_days": "dataRefreshWindowDays",
    "data_source_id": "dataSourceId",
    "database_encryption": "databaseEncryption",
    "database_version": "databaseVersion",
    "dataflow_custom_endpoint": "dataflowCustomEndpoint",
    "dataproc_beta_custom_endpoint": "dataprocBetaCustomEndpoint",
    "dataproc_custom_endpoint": "dataprocCustomEndpoint",
    "dataset_id": "datasetId",
    "default_acl": "defaultAcl",
    "default_admission_rule": "defaultAdmissionRule",
    "default_bucket": "defaultBucket",
    "default_encryption_configuration": "defaultEncryptionConfiguration",
    "default_hostname": "defaultHostname",
    "default_max_pods_per_node": "defaultMaxPodsPerNode",
    "default_partition_expiration_ms": "defaultPartitionExpirationMs",
    "default_port": "defaultPort",
    "default_service": "defaultService",
    "default_table_expiration_ms": "defaultTableExpirationMs",
    "default_version": "defaultVersion",
    "delete_contents_on_destroy": "deleteContentsOnDestroy",
    "delete_default_routes_on_create": "deleteDefaultRoutesOnCreate",
    "delete_service_on_destroy": "deleteServiceOnDestroy",
    "deletion_protection": "deletionProtection",
    "deletion_time": "deletionTime",
    "dest_range": "destRange",
    "destination_dataset_id": "destinationDatasetId",
    "destination_ranges": "destinationRanges",
    "detailed_status": "detailedStatus",
    "detect_md5hash": "detectMd5hash",
    "device_name": "deviceName",
    "dicom_store_id": "dicomStoreId",
    "disable_dependent_services": "disableDependentServices",
    "disable_on_destroy": "disableOnDestroy",
    "disable_referential_integrity": "disableReferentialIntegrity",
    "disable_resource_versioning": "disableResourceVersioning",
    "disk_encryption_key": "diskEncryptionKey",
    "disk_size_gb": "diskSizeGb",
    "dispatch_rules": "dispatchRules",
    "display_name": "displayName",
    "distribution_policy_zones": "distributionPolicyZones",
    "dns_address": "dnsAddress",
    "dns_beta_custom_endpoint": "dnsBetaCustomEndpoint",
    "dns_custom_endpoint": "dnsCustomEndpoint",
    "dns_name": "dnsName",
    "dnssec_config": "dnssecConfig",
    "domain_name": "domainName",
    "drain_nat_ips": "drainNatIps",
    "driver_controls_files_uri": "driverControlsFilesUri",
    "driver_output_resource_uri": "driverOutputResourceUri",
    "edge_availability_domain": "edgeAvailabilityDomain",
    "enable_binary_authorization": "enableBinaryAuthorization",
    "enable_cdn": "enableCdn",
    "enable_flow_logs": "enableFlowLogs",
    "enable_history_import": "enableHistoryImport",
    "enable_inbound_forwarding": "enableInboundForwarding",
    "enable_intranode_visibility": "enableIntranodeVisibility",
    "enable_kubernetes_alpha": "enableKubernetesAlpha",
    "enable_legacy_abac": "enableLegacyAbac",
    "enable_logging": "enableLogging",
    "enable_shielded_nodes": "enableShieldedNodes",
    "enable_tpu": "enableTpu",
    "enable_update_create": "enableUpdateCreate",
    "enabled_features": "enabledFeatures",
    "entity_id": "entityId",
    "entry_point": "entryPoint",
    "env_variables": "envVariables",
    "environment_variables": "environmentVariables",
    "event_notification_config": "eventNotificationConfig",
    "event_notification_configs": "eventNotificationConfigs",
    "event_trigger": "eventTrigger",
    "event_types": "eventTypes",
    "expiration_policy": "expirationPolicy",
    "expiration_time": "expirationTime",
    "expire_time": "expireTime",
    "export_custom_routes": "exportCustomRoutes",
    "export_to_security_command_center": "exportToSecurityCommandCenter",
    "external_data_configuration": "externalDataConfiguration",
    "failover_policy": "failoverPolicy",
    "failover_ratio": "failoverRatio",
    "feature_settings": "featureSettings",
    "fhir_store_id": "fhirStoreId",
    "file_shares": "fileShares",
    "filestore_custom_endpoint": "filestoreCustomEndpoint",
    "firestore_custom_endpoint": "firestoreCustomEndpoint",
    "first_ip_address": "firstIpAddress",
    "folder_id": "folderId",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "forwarding_config": "forwardingConfig",
    "friendly_name": "friendlyName",
    "gateway_address": "gatewayAddress",
    "gateway_id": "gatewayId",
    "gateway_ipv4": "gatewayIpv4",
    "gcr_domain": "gcrDomain",
    "global_policy_evaluation_mode": "globalPolicyEvaluationMode",
    "google_reference_id": "googleReferenceId",
    "grpc_config": "grpcConfig",
    "guest_accelerators": "guestAccelerators",
    "guest_os_features": "guestOsFeatures",
    "hadoop_config": "hadoopConfig",
    "health_checks": "healthChecks",
    "healthcare_custom_endpoint": "healthcareCustomEndpoint",
    "healthy_threshold": "healthyThreshold",
    "hive_config": "hiveConfig",
    "hl7_v2_store_id": "hl7V2StoreId",
    "host_project": "hostProject",
    "host_rules": "hostRules",
    "http2_health_check": "http2HealthCheck",
    "http_check": "httpCheck",
    "http_config": "httpConfig",
    "http_enabled_state": "httpEnabledState",
    "http_health_check": "httpHealthCheck",
    "http_target": "httpTarget",
    "https_health_check": "httpsHealthCheck",
    "https_trigger_url": "httpsTriggerUrl",
    "iam_credentials_custom_endpoint": "iamCredentialsCustomEndpoint",
    "iam_custom_endpoint": "iamCustomEndpoint",
    "iap_custom_endpoint": "iapCustomEndpoint",
    "icmp_idle_timeout_sec": "icmpIdleTimeoutSec",
    "ignore_warnings": "ignoreWarnings",
    "ignored_files": "ignoredFiles",
    "ike_version": "ikeVersion",
    "import_custom_routes": "importCustomRoutes",
    "include_children": "includeChildren",
    "included_files": "includedFiles",
    "initial_node_count": "initialNodeCount",
    "instance_class": "instanceClass",
    "instance_description": "instanceDescription",
    "instance_group": "instanceGroup",
    "instance_group_urls": "instanceGroupUrls",
    "instance_id": "instanceId",
    "instance_name": "instanceName",
    "instance_type": "instanceType",
    "interconnect_attachment": "interconnectAttachment",
    "internal_checkers": "internalCheckers",
    "ip_address": "ipAddress",
    "ip_addresses": "ipAddresses",
    "ip_allocation_policy": "ipAllocationPolicy",
    "ip_cidr_range": "ipCidrRange",
    "ip_configuration": "ipConfiguration",
    "ip_protocol": "ipProtocol",
    "ip_range": "ipRange",
    "ip_version": "ipVersion",
    "ipv4_range": "ipv4Range",
    "is_cluster": "isCluster",
    "is_internal": "isInternal",
    "job_id": "jobId",
    "key_algorithm": "keyAlgorithm",
    "key_ring": "keyRing",
    "key_ring_id": "keyRingId",
    "key_value": "keyValue",
    "kms_custom_endpoint": "kmsCustomEndpoint",
    "kms_key_name": "kmsKeyName",
    "label_extractors": "labelExtractors",
    "label_fingerprint": "labelFingerprint",
    "last_attach_timestamp": "lastAttachTimestamp",
    "last_detach_timestamp": "lastDetachTimestamp",
    "last_modification_time": "lastModificationTime",
    "last_modified_time": "lastModifiedTime",
    "lifecycle_rules": "lifecycleRules",
    "lifecycle_state": "lifecycleState",
    "list_policy": "listPolicy",
    "load_balancing_scheme": "loadBalancingScheme",
    "local_traffic_selectors": "localTrafficSelectors",
    "locality_lb_policy": "localityLbPolicy",
    "location_id": "locationId",
    "log_config": "logConfig",
    "log_level": "logLevel",
    "logging_custom_endpoint": "loggingCustomEndpoint",
    "logging_service": "loggingService",
    "machine_type": "machineType",
    "maintenance_policy": "maintenancePolicy",
    "managed_zone": "managedZone",
    "map_id": "mapId",
    "master_auth": "masterAuth",
    "master_authorized_networks_config": "masterAuthorizedNetworksConfig",
    "master_instance_name": "masterInstanceName",
    "master_version": "masterVersion",
    "max_ages": "maxAges",
    "max_instances": "maxInstances",
    "max_pods_per_node": "maxPodsPerNode",
    "max_qps": "maxQps",
    "max_throughput": "maxThroughput",
    "max_versions": "maxVersions",
    "max_workers": "maxWorkers",
    "memory_size_gb": "memorySizeGb",
    "message_retention_duration": "messageRetentionDuration",
    "message_storage_policy": "messageStoragePolicy",
    "metadata_filters": "metadataFilters",
    "metadata_fingerprint": "metadataFingerprint",
    "metadata_startup_script": "metadataStartupScript",
    "metric_descriptor": "metricDescriptor",
    "min_cpu_platform": "minCpuPlatform",
    "min_master_version": "minMasterVersion",
    "min_ports_per_vm": "minPortsPerVm",
    "min_throughput": "minThroughput",
    "min_tls_version": "minTlsVersion",
    "ml_engine_custom_endpoint": "mlEngineCustomEndpoint",
    "monitored_resource": "monitoredResource",
    "monitoring_custom_endpoint": "monitoringCustomEndpoint",
    "monitoring_service": "monitoringService",
    "mqtt_config": "mqttConfig",
    "mqtt_enabled_state": "mqttEnabledState",
    "multi_cluster_routing_use_any": "multiClusterRoutingUseAny",
    "name_prefix": "namePrefix",
    "name_servers": "nameServers",
    "named_ports": "namedPorts",
    "nat_ip_allocate_option": "natIpAllocateOption",
    "nat_ips": "natIps",
    "nat_policy": "natPolicy",
    "network_endpoint_group": "networkEndpointGroup",
    "network_endpoint_type": "networkEndpointType",
    "network_endpoints": "networkEndpoints",
    "network_interfaces": "networkInterfaces",
    "network_policy": "networkPolicy",
    "network_tier": "networkTier",
    "next_hop_gateway": "nextHopGateway",
    "next_hop_ilb": "nextHopIlb",
    "next_hop_instance": "nextHopInstance",
    "next_hop_instance_zone": "nextHopInstanceZone",
    "next_hop_ip": "nextHopIp",
    "next_hop_network": "nextHopNetwork",
    "next_hop_vpn_tunnel": "nextHopVpnTunnel",
    "node_affinity_labels": "nodeAffinityLabels",
    "node_config": "nodeConfig",
    "node_count": "nodeCount",
    "node_locations": "nodeLocations",
    "node_pools": "nodePools",
    "node_template": "nodeTemplate",
    "node_type": "nodeType",
    "node_type_flexibility": "nodeTypeFlexibility",
    "node_version": "nodeVersion",
    "noop_on_destroy": "noopOnDestroy",
    "notification_channels": "notificationChannels",
    "notification_config": "notificationConfig",
    "num_bytes": "numBytes",
    "num_long_term_bytes": "numLongTermBytes",
    "num_nodes": "numNodes",
    "num_rows": "numRows",
    "object_name_prefix": "objectNamePrefix",
    "on_delete": "onDelete",
    "online_prediction_console_logging": "onlinePredictionConsoleLogging",
    "online_prediction_logging": "onlinePredictionLogging",
    "openapi_config": "openapiConfig",
    "org_id": "orgId",
    "outlier_detection": "outlierDetection",
    "output_name": "outputName",
    "override_strategy": "overrideStrategy",
    "pairing_key": "pairingKey",
    "parent_name": "parentName",
    "parser_config": "parserConfig",
    "partner_asn": "partnerAsn",
    "path_matchers": "pathMatchers",
    "payload_format": "payloadFormat",
    "peer_asn": "peerAsn",
    "peer_external_gateway": "peerExternalGateway",
    "peer_external_gateway_interface": "peerExternalGatewayInterface",
    "peer_gcp_gateway": "peerGcpGateway",
    "peer_ip": "peerIp",
    "peer_ip_address": "peerIpAddress",
    "peer_network": "peerNetwork",
    "peering_config": "peeringConfig",
    "perimeter_type": "perimeterType",
    "pgp_key": "pgpKey",
    "physical_block_size_bytes": "physicalBlockSizeBytes",
    "pig_config": "pigConfig",
    "pod_security_policy_config": "podSecurityPolicyConfig",
    "policy_data": "policyData",
    "policy_id": "policyId",
    "port_name": "portName",
    "port_range": "portRange",
    "predefined_acl": "predefinedAcl",
    "prefix_length": "prefixLength",
    "private_cluster_config": "privateClusterConfig",
    "private_interconnect_info": "privateInterconnectInfo",
    "private_ip_address": "privateIpAddress",
    "private_ip_google_access": "privateIpGoogleAccess",
    "private_key": "privateKey",
    "private_key_encrypted": "privateKeyEncrypted",
    "private_key_fingerprint": "privateKeyFingerprint",
    "private_key_type": "privateKeyType",
    "private_visibility_config": "privateVisibilityConfig",
    "project_id": "projectId",
    "project_team": "projectTeam",
    "protoc_output_base64": "protocOutputBase64",
    "proxy_header": "proxyHeader",
    "proxy_id": "proxyId",
    "public_ip_address": "publicIpAddress",
    "public_key": "publicKey",
    "public_key_type": "publicKeyType",
    "pubsub_custom_endpoint": "pubsubCustomEndpoint",
    "pubsub_target": "pubsubTarget",
    "pubsub_topic_name": "pubsubTopicName",
    "push_config": "pushConfig",
    "pyspark_config": "pysparkConfig",
    "query_scope": "queryScope",
    "quic_override": "quicOverride",
    "raw_disk": "rawDisk",
    "redis_configs": "redisConfigs",
    "redis_custom_endpoint": "redisCustomEndpoint",
    "redis_version": "redisVersion",
    "redundancy_type": "redundancyType",
    "release_channel": "releaseChannel",
    "remote_traffic_selectors": "remoteTrafficSelectors",
    "remove_default_node_pool": "removeDefaultNodePool",
    "replica_configuration": "replicaConfiguration",
    "replica_zones": "replicaZones",
    "request_path": "requestPath",
    "requester_pays": "requesterPays",
    "reserved_ip_range": "reservedIpRange",
    "reserved_peering_ranges": "reservedPeeringRanges",
    "resource_group": "resourceGroup",
    "resource_labels": "resourceLabels",
    "resource_manager_custom_endpoint": "resourceManagerCustomEndpoint",
    "resource_manager_v2beta1_custom_endpoint": "resourceManagerV2beta1CustomEndpoint",
    "resource_policies": "resourcePolicies",
    "resource_records": "resourceRecords",
    "resource_usage_export_config": "resourceUsageExportConfig",
    "restore_policy": "restorePolicy",
    "retain_acked_messages": "retainAckedMessages",
    "retention_policy": "retentionPolicy",
    "retry_config": "retryConfig",
    "role_entities": "roleEntities",
    "role_id": "roleId",
    "rotation_period": "rotationPeriod",
    "routing_mode": "routingMode",
    "runtime_api_version": "runtimeApiVersion",
    "runtime_config_custom_endpoint": "runtimeConfigCustomEndpoint",
    "runtimeconfig_custom_endpoint": "runtimeconfigCustomEndpoint",
    "scheduling_config": "schedulingConfig",
    "scratch_disks": "scratchDisks",
    "secondary_ip_ranges": "secondaryIpRanges",
    "secondary_worker_config": "secondaryWorkerConfig",
    "security_center_custom_endpoint": "securityCenterCustomEndpoint",
    "security_policy": "securityPolicy",
    "security_scanner_custom_endpoint": "securityScannerCustomEndpoint",
    "selected_regions": "selectedRegions",
    "self_link": "selfLink",
    "server_binding": "serverBinding",
    "server_ca_cert": "serverCaCert",
    "service_account": "serviceAccount",
    "service_account_email": "serviceAccountEmail",
    "service_account_email_address": "serviceAccountEmailAddress",
    "service_account_id": "serviceAccountId",
    "service_label": "serviceLabel",
    "service_management_custom_endpoint": "serviceManagementCustomEndpoint",
    "service_name": "serviceName",
    "service_networking_custom_endpoint": "serviceNetworkingCustomEndpoint",
    "service_project": "serviceProject",
    "service_usage_custom_endpoint": "serviceUsageCustomEndpoint",
    "services_ipv4_cidr": "servicesIpv4Cidr",
    "serving_status": "servingStatus",
    "session_affinity": "sessionAffinity",
    "sha1_fingerprint": "sha1Fingerprint",
    "shared_secret": "sharedSecret",
    "shared_secret_hash": "sharedSecretHash",
    "shielded_instance_config": "shieldedInstanceConfig",
    "single_cluster_routing": "singleClusterRouting",
    "skip_delete": "skipDelete",
    "snapshot_encryption_key": "snapshotEncryptionKey",
    "snapshot_id": "snapshotId",
    "snapshot_schedule_policy": "snapshotSchedulePolicy",
    "source_archive_bucket": "sourceArchiveBucket",
    "source_archive_object": "sourceArchiveObject",
    "source_disk": "sourceDisk",
    "source_disk_encryption_key": "sourceDiskEncryptionKey",
    "source_disk_link": "sourceDiskLink",
    "source_image_encryption_key": "sourceImageEncryptionKey",
    "source_image_id": "sourceImageId",
    "source_instance_template": "sourceInstanceTemplate",
    "source_range": "sourceRange",
    "source_ranges": "sourceRanges",
    "source_repo_custom_endpoint": "sourceRepoCustomEndpoint",
    "source_repository": "sourceRepository",
    "source_service_accounts": "sourceServiceAccounts",
    "source_snapshot_encryption_key": "sourceSnapshotEncryptionKey",
    "source_snapshot_id": "sourceSnapshotId",
    "source_subnetwork_ip_ranges_to_nat": "sourceSubnetworkIpRangesToNat",
    "source_tags": "sourceTags",
    "spanner_custom_endpoint": "spannerCustomEndpoint",
    "spark_config": "sparkConfig",
    "sparksql_config": "sparksqlConfig",
    "specific_reservation": "specificReservation",
    "specific_reservation_required": "specificReservationRequired",
    "split_keys": "splitKeys",
    "sql_custom_endpoint": "sqlCustomEndpoint",
    "ssl_certificates": "sslCertificates",
    "ssl_health_check": "sslHealthCheck",
    "ssl_policy": "sslPolicy",
    "ssl_settings": "sslSettings",
    "starting_urls": "startingUrls",
    "state_details": "stateDetails",
    "state_notification_config": "stateNotificationConfig",
    "storage_bytes": "storageBytes",
    "storage_class": "storageClass",
    "storage_custom_endpoint": "storageCustomEndpoint",
    "storage_transfer_custom_endpoint": "storageTransferCustomEndpoint",
    "subject_alternative_names": "subjectAlternativeNames",
    "table_id": "tableId",
    "tags_fingerprint": "tagsFingerprint",
    "target_platforms": "targetPlatforms",
    "target_pools": "targetPools",
    "target_service_accounts": "targetServiceAccounts",
    "target_size": "targetSize",
    "target_tags": "targetTags",
    "target_vpn_gateway": "targetVpnGateway",
    "tcp_check": "tcpCheck",
    "tcp_established_idle_timeout_sec": "tcpEstablishedIdleTimeoutSec",
    "tcp_health_check": "tcpHealthCheck",
    "tcp_transitory_idle_timeout_sec": "tcpTransitoryIdleTimeoutSec",
    "temp_gcs_location": "tempGcsLocation",
    "template_gcs_path": "templateGcsPath",
    "tensorflow_version": "tensorflowVersion",
    "time_partitioning": "timePartitioning",
    "time_zone": "timeZone",
    "timeout_sec": "timeoutSec",
    "tpu_custom_endpoint": "tpuCustomEndpoint",
    "tpu_ipv4_cidr_block": "tpuIpv4CidrBlock",
    "transfer_spec": "transferSpec",
    "trigger_http": "triggerHttp",
    "trigger_id": "triggerId",
    "trigger_template": "triggerTemplate",
    "tunnel_id": "tunnelId",
    "udp_idle_timeout_sec": "udpIdleTimeoutSec",
    "unhealthy_threshold": "unhealthyThreshold",
    "unique_id": "uniqueId",
    "unique_writer_identity": "uniqueWriterIdentity",
    "update_policy": "updatePolicy",
    "update_time": "updateTime",
    "uptime_check_id": "uptimeCheckId",
    "url_dispatch_rules": "urlDispatchRules",
    "url_map": "urlMap",
    "user_agent": "userAgent",
    "user_labels": "userLabels",
    "user_project_override": "userProjectOverride",
    "valid_after": "validAfter",
    "valid_before": "validBefore",
    "value_extractor": "valueExtractor",
    "verification_status": "verificationStatus",
    "version_id": "versionId",
    "version_template": "versionTemplate",
    "vertical_pod_autoscaling": "verticalPodAutoscaling",
    "vlan_tag8021q": "vlanTag8021q",
    "vpc_access_custom_endpoint": "vpcAccessCustomEndpoint",
    "vpc_connector": "vpcConnector",
    "vpn_gateway": "vpnGateway",
    "vpn_gateway_interface": "vpnGatewayInterface",
    "vpn_interfaces": "vpnInterfaces",
    "vpn_tunnel": "vpnTunnel",
    "wait_for_instances": "waitForInstances",
    "web_backend_service": "webBackendService",
    "worker_config": "workerConfig",
    "workload_identity_config": "workloadIdentityConfig",
    "writer_identity": "writerIdentity",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceleratorType": "accelerator_type",
    "accessContextManagerCustomEndpoint": "access_context_manager_custom_endpoint",
    "accessToken": "access_token",
    "accountId": "account_id",
    "ackDeadlineSeconds": "ack_deadline_seconds",
    "additionalZones": "additional_zones",
    "addonsConfig": "addons_config",
    "addressType": "address_type",
    "adminEnabled": "admin_enabled",
    "admissionWhitelistPatterns": "admission_whitelist_patterns",
    "advertiseMode": "advertise_mode",
    "advertisedGroups": "advertised_groups",
    "advertisedIpRanges": "advertised_ip_ranges",
    "advertisedRoutePriority": "advertised_route_priority",
    "affinityCookieTtlSec": "affinity_cookie_ttl_sec",
    "allPorts": "all_ports",
    "allowStoppingForUpdate": "allow_stopping_for_update",
    "alternativeLocationId": "alternative_location_id",
    "alternativeNameServerConfig": "alternative_name_server_config",
    "appEngineCustomEndpoint": "app_engine_custom_endpoint",
    "appEngineHttpTarget": "app_engine_http_target",
    "appId": "app_id",
    "appProfileId": "app_profile_id",
    "archiveSizeBytes": "archive_size_bytes",
    "attachedDisks": "attached_disks",
    "attestationAuthority": "attestation_authority",
    "attestationAuthorityNote": "attestation_authority_note",
    "auditLogConfigs": "audit_log_configs",
    "authDomain": "auth_domain",
    "authenticatorGroupsConfig": "authenticator_groups_config",
    "authorizedNetwork": "authorized_network",
    "autoCreateNetwork": "auto_create_network",
    "autoCreateRoutes": "auto_create_routes",
    "autoCreateSubnetworks": "auto_create_subnetworks",
    "autoHealingPolicies": "auto_healing_policies",
    "autoscalingPolicy": "autoscaling_policy",
    "availableMemoryMb": "available_memory_mb",
    "backendBucket": "backend_bucket",
    "backendService": "backend_service",
    "backupPool": "backup_pool",
    "baseInstanceName": "base_instance_name",
    "basicAlgorithm": "basic_algorithm",
    "bigQueryCustomEndpoint": "big_query_custom_endpoint",
    "bigqueryDataTransferCustomEndpoint": "bigquery_data_transfer_custom_endpoint",
    "bigtableCustomEndpoint": "bigtable_custom_endpoint",
    "billingAccount": "billing_account",
    "billingAccountId": "billing_account_id",
    "binaryAuthorizationCustomEndpoint": "binary_authorization_custom_endpoint",
    "blacklistPatterns": "blacklist_patterns",
    "booleanPolicy": "boolean_policy",
    "bootDisk": "boot_disk",
    "bucketName": "bucket_name",
    "bucketOptions": "bucket_options",
    "bucketPolicyOnly": "bucket_policy_only",
    "cacheControl": "cache_control",
    "canIpForward": "can_ip_forward",
    "candidateSubnets": "candidate_subnets",
    "cdnPolicy": "cdn_policy",
    "certSerialNumber": "cert_serial_number",
    "certificateId": "certificate_id",
    "checkIntervalSec": "check_interval_sec",
    "cidrBlock": "cidr_block",
    "circuitBreakers": "circuit_breakers",
    "cloudBillingCustomEndpoint": "cloud_billing_custom_endpoint",
    "cloudBuildCustomEndpoint": "cloud_build_custom_endpoint",
    "cloudFunction": "cloud_function",
    "cloudFunctionsCustomEndpoint": "cloud_functions_custom_endpoint",
    "cloudIotCustomEndpoint": "cloud_iot_custom_endpoint",
    "cloudRouterIpAddress": "cloud_router_ip_address",
    "cloudRunCustomEndpoint": "cloud_run_custom_endpoint",
    "cloudSchedulerCustomEndpoint": "cloud_scheduler_custom_endpoint",
    "clusterAdmissionRules": "cluster_admission_rules",
    "clusterAutoscaling": "cluster_autoscaling",
    "clusterConfig": "cluster_config",
    "clusterIpv4Cidr": "cluster_ipv4_cidr",
    "codeBucket": "code_bucket",
    "columnFamilies": "column_families",
    "columnFamily": "column_family",
    "commonName": "common_name",
    "composerCustomEndpoint": "composer_custom_endpoint",
    "computeBetaCustomEndpoint": "compute_beta_custom_endpoint",
    "computeCustomEndpoint": "compute_custom_endpoint",
    "configId": "config_id",
    "connectionDrainingTimeoutSec": "connection_draining_timeout_sec",
    "connectionName": "connection_name",
    "consistentHash": "consistent_hash",
    "containerAnalysisCustomEndpoint": "container_analysis_custom_endpoint",
    "containerBetaCustomEndpoint": "container_beta_custom_endpoint",
    "containerCustomEndpoint": "container_custom_endpoint",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentLanguage": "content_language",
    "contentMatchers": "content_matchers",
    "contentType": "content_type",
    "cpuPlatform": "cpu_platform",
    "createTime": "create_time",
    "creationRecord": "creation_record",
    "creationTime": "creation_time",
    "creationTimestamp": "creation_timestamp",
    "cryptoKeyId": "crypto_key_id",
    "currentLocationId": "current_location_id",
    "customAttributes": "custom_attributes",
    "customFeatures": "custom_features",
    "customRequestHeaders": "custom_request_headers",
    "customerRouterIpAddress": "customer_router_ip_address",
    "dataRefreshWindowDays": "data_refresh_window_days",
    "dataSourceId": "data_source_id",
    "databaseEncryption": "database_encryption",
    "databaseVersion": "database_version",
    "dataflowCustomEndpoint": "dataflow_custom_endpoint",
    "dataprocBetaCustomEndpoint": "dataproc_beta_custom_endpoint",
    "dataprocCustomEndpoint": "dataproc_custom_endpoint",
    "datasetId": "dataset_id",
    "defaultAcl": "default_acl",
    "defaultAdmissionRule": "default_admission_rule",
    "defaultBucket": "default_bucket",
    "defaultEncryptionConfiguration": "default_encryption_configuration",
    "defaultHostname": "default_hostname",
    "defaultMaxPodsPerNode": "default_max_pods_per_node",
    "defaultPartitionExpirationMs": "default_partition_expiration_ms",
    "defaultPort": "default_port",
    "defaultService": "default_service",
    "defaultTableExpirationMs": "default_table_expiration_ms",
    "defaultVersion": "default_version",
    "deleteContentsOnDestroy": "delete_contents_on_destroy",
    "deleteDefaultRoutesOnCreate": "delete_default_routes_on_create",
    "deleteServiceOnDestroy": "delete_service_on_destroy",
    "deletionProtection": "deletion_protection",
    "deletionTime": "deletion_time",
    "destRange": "dest_range",
    "destinationDatasetId": "destination_dataset_id",
    "destinationRanges": "destination_ranges",
    "detailedStatus": "detailed_status",
    "detectMd5hash": "detect_md5hash",
    "deviceName": "device_name",
    "dicomStoreId": "dicom_store_id",
    "disableDependentServices": "disable_dependent_services",
    "disableOnDestroy": "disable_on_destroy",
    "disableReferentialIntegrity": "disable_referential_integrity",
    "disableResourceVersioning": "disable_resource_versioning",
    "diskEncryptionKey": "disk_encryption_key",
    "diskSizeGb": "disk_size_gb",
    "dispatchRules": "dispatch_rules",
    "displayName": "display_name",
    "distributionPolicyZones": "distribution_policy_zones",
    "dnsAddress": "dns_address",
    "dnsBetaCustomEndpoint": "dns_beta_custom_endpoint",
    "dnsCustomEndpoint": "dns_custom_endpoint",
    "dnsName": "dns_name",
    "dnssecConfig": "dnssec_config",
    "domainName": "domain_name",
    "drainNatIps": "drain_nat_ips",
    "driverControlsFilesUri": "driver_controls_files_uri",
    "driverOutputResourceUri": "driver_output_resource_uri",
    "edgeAvailabilityDomain": "edge_availability_domain",
    "enableBinaryAuthorization": "enable_binary_authorization",
    "enableCdn": "enable_cdn",
    "enableFlowLogs": "enable_flow_logs",
    "enableHistoryImport": "enable_history_import",
    "enableInboundForwarding": "enable_inbound_forwarding",
    "enableIntranodeVisibility": "enable_intranode_visibility",
    "enableKubernetesAlpha": "enable_kubernetes_alpha",
    "enableLegacyAbac": "enable_legacy_abac",
    "enableLogging": "enable_logging",
    "enableShieldedNodes": "enable_shielded_nodes",
    "enableTpu": "enable_tpu",
    "enableUpdateCreate": "enable_update_create",
    "enabledFeatures": "enabled_features",
    "entityId": "entity_id",
    "entryPoint": "entry_point",
    "envVariables": "env_variables",
    "environmentVariables": "environment_variables",
    "eventNotificationConfig": "event_notification_config",
    "eventNotificationConfigs": "event_notification_configs",
    "eventTrigger": "event_trigger",
    "eventTypes": "event_types",
    "expirationPolicy": "expiration_policy",
    "expirationTime": "expiration_time",
    "expireTime": "expire_time",
    "exportCustomRoutes": "export_custom_routes",
    "exportToSecurityCommandCenter": "export_to_security_command_center",
    "externalDataConfiguration": "external_data_configuration",
    "failoverPolicy": "failover_policy",
    "failoverRatio": "failover_ratio",
    "featureSettings": "feature_settings",
    "fhirStoreId": "fhir_store_id",
    "fileShares": "file_shares",
    "filestoreCustomEndpoint": "filestore_custom_endpoint",
    "firestoreCustomEndpoint": "firestore_custom_endpoint",
    "firstIpAddress": "first_ip_address",
    "folderId": "folder_id",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "forwardingConfig": "forwarding_config",
    "friendlyName": "friendly_name",
    "gatewayAddress": "gateway_address",
    "gatewayId": "gateway_id",
    "gatewayIpv4": "gateway_ipv4",
    "gcrDomain": "gcr_domain",
    "globalPolicyEvaluationMode": "global_policy_evaluation_mode",
    "googleReferenceId": "google_reference_id",
    "grpcConfig": "grpc_config",
    "guestAccelerators": "guest_accelerators",
    "guestOsFeatures": "guest_os_features",
    "hadoopConfig": "hadoop_config",
    "healthChecks": "health_checks",
    "healthcareCustomEndpoint": "healthcare_custom_endpoint",
    "healthyThreshold": "healthy_threshold",
    "hiveConfig": "hive_config",
    "hl7V2StoreId": "hl7_v2_store_id",
    "hostProject": "host_project",
    "hostRules": "host_rules",
    "http2HealthCheck": "http2_health_check",
    "httpCheck": "http_check",
    "httpConfig": "http_config",
    "httpEnabledState": "http_enabled_state",
    "httpHealthCheck": "http_health_check",
    "httpTarget": "http_target",
    "httpsHealthCheck": "https_health_check",
    "httpsTriggerUrl": "https_trigger_url",
    "iamCredentialsCustomEndpoint": "iam_credentials_custom_endpoint",
    "iamCustomEndpoint": "iam_custom_endpoint",
    "iapCustomEndpoint": "iap_custom_endpoint",
    "icmpIdleTimeoutSec": "icmp_idle_timeout_sec",
    "ignoreWarnings": "ignore_warnings",
    "ignoredFiles": "ignored_files",
    "ikeVersion": "ike_version",
    "importCustomRoutes": "import_custom_routes",
    "includeChildren": "include_children",
    "includedFiles": "included_files",
    "initialNodeCount": "initial_node_count",
    "instanceClass": "instance_class",
    "instanceDescription": "instance_description",
    "instanceGroup": "instance_group",
    "instanceGroupUrls": "instance_group_urls",
    "instanceId": "instance_id",
    "instanceName": "instance_name",
    "instanceType": "instance_type",
    "interconnectAttachment": "interconnect_attachment",
    "internalCheckers": "internal_checkers",
    "ipAddress": "ip_address",
    "ipAddresses": "ip_addresses",
    "ipAllocationPolicy": "ip_allocation_policy",
    "ipCidrRange": "ip_cidr_range",
    "ipConfiguration": "ip_configuration",
    "ipProtocol": "ip_protocol",
    "ipRange": "ip_range",
    "ipVersion": "ip_version",
    "ipv4Range": "ipv4_range",
    "isCluster": "is_cluster",
    "isInternal": "is_internal",
    "jobId": "job_id",
    "keyAlgorithm": "key_algorithm",
    "keyRing": "key_ring",
    "keyRingId": "key_ring_id",
    "keyValue": "key_value",
    "kmsCustomEndpoint": "kms_custom_endpoint",
    "kmsKeyName": "kms_key_name",
    "labelExtractors": "label_extractors",
    "labelFingerprint": "label_fingerprint",
    "lastAttachTimestamp": "last_attach_timestamp",
    "lastDetachTimestamp": "last_detach_timestamp",
    "lastModificationTime": "last_modification_time",
    "lastModifiedTime": "last_modified_time",
    "lifecycleRules": "lifecycle_rules",
    "lifecycleState": "lifecycle_state",
    "listPolicy": "list_policy",
    "loadBalancingScheme": "load_balancing_scheme",
    "localTrafficSelectors": "local_traffic_selectors",
    "localityLbPolicy": "locality_lb_policy",
    "locationId": "location_id",
    "logConfig": "log_config",
    "logLevel": "log_level",
    "loggingCustomEndpoint": "logging_custom_endpoint",
    "loggingService": "logging_service",
    "machineType": "machine_type",
    "maintenancePolicy": "maintenance_policy",
    "managedZone": "managed_zone",
    "mapId": "map_id",
    "masterAuth": "master_auth",
    "masterAuthorizedNetworksConfig": "master_authorized_networks_config",
    "masterInstanceName": "master_instance_name",
    "masterVersion": "master_version",
    "maxAges": "max_ages",
    "maxInstances": "max_instances",
    "maxPodsPerNode": "max_pods_per_node",
    "maxQps": "max_qps",
    "maxThroughput": "max_throughput",
    "maxVersions": "max_versions",
    "maxWorkers": "max_workers",
    "memorySizeGb": "memory_size_gb",
    "messageRetentionDuration": "message_retention_duration",
    "messageStoragePolicy": "message_storage_policy",
    "metadataFilters": "metadata_filters",
    "metadataFingerprint": "metadata_fingerprint",
    "metadataStartupScript": "metadata_startup_script",
    "metricDescriptor": "metric_descriptor",
    "minCpuPlatform": "min_cpu_platform",
    "minMasterVersion": "min_master_version",
    "minPortsPerVm": "min_ports_per_vm",
    "minThroughput": "min_throughput",
    "minTlsVersion": "min_tls_version",
    "mlEngineCustomEndpoint": "ml_engine_custom_endpoint",
    "monitoredResource": "monitored_resource",
    "monitoringCustomEndpoint": "monitoring_custom_endpoint",
    "monitoringService": "monitoring_service",
    "mqttConfig": "mqtt_config",
    "mqttEnabledState": "mqtt_enabled_state",
    "multiClusterRoutingUseAny": "multi_cluster_routing_use_any",
    "namePrefix": "name_prefix",
    "nameServers": "name_servers",
    "namedPorts": "named_ports",
    "natIpAllocateOption": "nat_ip_allocate_option",
    "natIps": "nat_ips",
    "natPolicy": "nat_policy",
    "networkEndpointGroup": "network_endpoint_group",
    "networkEndpointType": "network_endpoint_type",
    "networkEndpoints": "network_endpoints",
    "networkInterfaces": "network_interfaces",
    "networkPolicy": "network_policy",
    "networkTier": "network_tier",
    "nextHopGateway": "next_hop_gateway",
    "nextHopIlb": "next_hop_ilb",
    "nextHopInstance": "next_hop_instance",
    "nextHopInstanceZone": "next_hop_instance_zone",
    "nextHopIp": "next_hop_ip",
    "nextHopNetwork": "next_hop_network",
    "nextHopVpnTunnel": "next_hop_vpn_tunnel",
    "nodeAffinityLabels": "node_affinity_labels",
    "nodeConfig": "node_config",
    "nodeCount": "node_count",
    "nodeLocations": "node_locations",
    "nodePools": "node_pools",
    "nodeTemplate": "node_template",
    "nodeType": "node_type",
    "nodeTypeFlexibility": "node_type_flexibility",
    "nodeVersion": "node_version",
    "noopOnDestroy": "noop_on_destroy",
    "notificationChannels": "notification_channels",
    "notificationConfig": "notification_config",
    "numBytes": "num_bytes",
    "numLongTermBytes": "num_long_term_bytes",
    "numNodes": "num_nodes",
    "numRows": "num_rows",
    "objectNamePrefix": "object_name_prefix",
    "onDelete": "on_delete",
    "onlinePredictionConsoleLogging": "online_prediction_console_logging",
    "onlinePredictionLogging": "online_prediction_logging",
    "openapiConfig": "openapi_config",
    "orgId": "org_id",
    "outlierDetection": "outlier_detection",
    "outputName": "output_name",
    "overrideStrategy": "override_strategy",
    "pairingKey": "pairing_key",
    "parentName": "parent_name",
    "parserConfig": "parser_config",
    "partnerAsn": "partner_asn",
    "pathMatchers": "path_matchers",
    "payloadFormat": "payload_format",
    "peerAsn": "peer_asn",
    "peerExternalGateway": "peer_external_gateway",
    "peerExternalGatewayInterface": "peer_external_gateway_interface",
    "peerGcpGateway": "peer_gcp_gateway",
    "peerIp": "peer_ip",
    "peerIpAddress": "peer_ip_address",
    "peerNetwork": "peer_network",
    "peeringConfig": "peering_config",
    "perimeterType": "perimeter_type",
    "pgpKey": "pgp_key",
    "physicalBlockSizeBytes": "physical_block_size_bytes",
    "pigConfig": "pig_config",
    "podSecurityPolicyConfig": "pod_security_policy_config",
    "policyData": "policy_data",
    "policyId": "policy_id",
    "portName": "port_name",
    "portRange": "port_range",
    "predefinedAcl": "predefined_acl",
    "prefixLength": "prefix_length",
    "privateClusterConfig": "private_cluster_config",
    "privateInterconnectInfo": "private_interconnect_info",
    "privateIpAddress": "private_ip_address",
    "privateIpGoogleAccess": "private_ip_google_access",
    "privateKey": "private_key",
    "privateKeyEncrypted": "private_key_encrypted",
    "privateKeyFingerprint": "private_key_fingerprint",
    "privateKeyType": "private_key_type",
    "privateVisibilityConfig": "private_visibility_config",
    "projectId": "project_id",
    "projectTeam": "project_team",
    "protocOutputBase64": "protoc_output_base64",
    "proxyHeader": "proxy_header",
    "proxyId": "proxy_id",
    "publicIpAddress": "public_ip_address",
    "publicKey": "public_key",
    "publicKeyType": "public_key_type",
    "pubsubCustomEndpoint": "pubsub_custom_endpoint",
    "pubsubTarget": "pubsub_target",
    "pubsubTopicName": "pubsub_topic_name",
    "pushConfig": "push_config",
    "pysparkConfig": "pyspark_config",
    "queryScope": "query_scope",
    "quicOverride": "quic_override",
    "rawDisk": "raw_disk",
    "redisConfigs": "redis_configs",
    "redisCustomEndpoint": "redis_custom_endpoint",
    "redisVersion": "redis_version",
    "redundancyType": "redundancy_type",
    "releaseChannel": "release_channel",
    "remoteTrafficSelectors": "remote_traffic_selectors",
    "removeDefaultNodePool": "remove_default_node_pool",
    "replicaConfiguration": "replica_configuration",
    "replicaZones": "replica_zones",
    "requestPath": "request_path",
    "requesterPays": "requester_pays",
    "reservedIpRange": "reserved_ip_range",
    "reservedPeeringRanges": "reserved_peering_ranges",
    "resourceGroup": "resource_group",
    "resourceLabels": "resource_labels",
    "resourceManagerCustomEndpoint": "resource_manager_custom_endpoint",
    "resourceManagerV2beta1CustomEndpoint": "resource_manager_v2beta1_custom_endpoint",
    "resourcePolicies": "resource_policies",
    "resourceRecords": "resource_records",
    "resourceUsageExportConfig": "resource_usage_export_config",
    "restorePolicy": "restore_policy",
    "retainAckedMessages": "retain_acked_messages",
    "retentionPolicy": "retention_policy",
    "retryConfig": "retry_config",
    "roleEntities": "role_entities",
    "roleId": "role_id",
    "rotationPeriod": "rotation_period",
    "routingMode": "routing_mode",
    "runtimeApiVersion": "runtime_api_version",
    "runtimeConfigCustomEndpoint": "runtime_config_custom_endpoint",
    "runtimeconfigCustomEndpoint": "runtimeconfig_custom_endpoint",
    "schedulingConfig": "scheduling_config",
    "scratchDisks": "scratch_disks",
    "secondaryIpRanges": "secondary_ip_ranges",
    "secondaryWorkerConfig": "secondary_worker_config",
    "securityCenterCustomEndpoint": "security_center_custom_endpoint",
    "securityPolicy": "security_policy",
    "securityScannerCustomEndpoint": "security_scanner_custom_endpoint",
    "selectedRegions": "selected_regions",
    "selfLink": "self_link",
    "serverBinding": "server_binding",
    "serverCaCert": "server_ca_cert",
    "serviceAccount": "service_account",
    "serviceAccountEmail": "service_account_email",
    "serviceAccountEmailAddress": "service_account_email_address",
    "serviceAccountId": "service_account_id",
    "serviceLabel": "service_label",
    "serviceManagementCustomEndpoint": "service_management_custom_endpoint",
    "serviceName": "service_name",
    "serviceNetworkingCustomEndpoint": "service_networking_custom_endpoint",
    "serviceProject": "service_project",
    "serviceUsageCustomEndpoint": "service_usage_custom_endpoint",
    "servicesIpv4Cidr": "services_ipv4_cidr",
    "servingStatus": "serving_status",
    "sessionAffinity": "session_affinity",
    "sha1Fingerprint": "sha1_fingerprint",
    "sharedSecret": "shared_secret",
    "sharedSecretHash": "shared_secret_hash",
    "shieldedInstanceConfig": "shielded_instance_config",
    "singleClusterRouting": "single_cluster_routing",
    "skipDelete": "skip_delete",
    "snapshotEncryptionKey": "snapshot_encryption_key",
    "snapshotId": "snapshot_id",
    "snapshotSchedulePolicy": "snapshot_schedule_policy",
    "sourceArchiveBucket": "source_archive_bucket",
    "sourceArchiveObject": "source_archive_object",
    "sourceDisk": "source_disk",
    "sourceDiskEncryptionKey": "source_disk_encryption_key",
    "sourceDiskLink": "source_disk_link",
    "sourceImageEncryptionKey": "source_image_encryption_key",
    "sourceImageId": "source_image_id",
    "sourceInstanceTemplate": "source_instance_template",
    "sourceRange": "source_range",
    "sourceRanges": "source_ranges",
    "sourceRepoCustomEndpoint": "source_repo_custom_endpoint",
    "sourceRepository": "source_repository",
    "sourceServiceAccounts": "source_service_accounts",
    "sourceSnapshotEncryptionKey": "source_snapshot_encryption_key",
    "sourceSnapshotId": "source_snapshot_id",
    "sourceSubnetworkIpRangesToNat": "source_subnetwork_ip_ranges_to_nat",
    "sourceTags": "source_tags",
    "spannerCustomEndpoint": "spanner_custom_endpoint",
    "sparkConfig": "spark_config",
    "sparksqlConfig": "sparksql_config",
    "specificReservation": "specific_reservation",
    "specificReservationRequired": "specific_reservation_required",
    "splitKeys": "split_keys",
    "sqlCustomEndpoint": "sql_custom_endpoint",
    "sslCertificates": "ssl_certificates",
    "sslHealthCheck": "ssl_health_check",
    "sslPolicy": "ssl_policy",
    "sslSettings": "ssl_settings",
    "startingUrls": "starting_urls",
    "stateDetails": "state_details",
    "stateNotificationConfig": "state_notification_config",
    "storageBytes": "storage_bytes",
    "storageClass": "storage_class",
    "storageCustomEndpoint": "storage_custom_endpoint",
    "storageTransferCustomEndpoint": "storage_transfer_custom_endpoint",
    "subjectAlternativeNames": "subject_alternative_names",
    "tableId": "table_id",
    "tagsFingerprint": "tags_fingerprint",
    "targetPlatforms": "target_platforms",
    "targetPools": "target_pools",
    "targetServiceAccounts": "target_service_accounts",
    "targetSize": "target_size",
    "targetTags": "target_tags",
    "targetVpnGateway": "target_vpn_gateway",
    "tcpCheck": "tcp_check",
    "tcpEstablishedIdleTimeoutSec": "tcp_established_idle_timeout_sec",
    "tcpHealthCheck": "tcp_health_check",
    "tcpTransitoryIdleTimeoutSec": "tcp_transitory_idle_timeout_sec",
    "tempGcsLocation": "temp_gcs_location",
    "templateGcsPath": "template_gcs_path",
    "tensorflowVersion": "tensorflow_version",
    "timePartitioning": "time_partitioning",
    "timeZone": "time_zone",
    "timeoutSec": "timeout_sec",
    "tpuCustomEndpoint": "tpu_custom_endpoint",
    "tpuIpv4CidrBlock": "tpu_ipv4_cidr_block",
    "transferSpec": "transfer_spec",
    "triggerHttp": "trigger_http",
    "triggerId": "trigger_id",
    "triggerTemplate": "trigger_template",
    "tunnelId": "tunnel_id",
    "udpIdleTimeoutSec": "udp_idle_timeout_sec",
    "unhealthyThreshold": "unhealthy_threshold",
    "uniqueId": "unique_id",
    "uniqueWriterIdentity": "unique_writer_identity",
    "updatePolicy": "update_policy",
    "updateTime": "update_time",
    "uptimeCheckId": "uptime_check_id",
    "urlDispatchRules": "url_dispatch_rules",
    "urlMap": "url_map",
    "userAgent": "user_agent",
    "userLabels": "user_labels",
    "userProjectOverride": "user_project_override",
    "validAfter": "valid_after",
    "validBefore": "valid_before",
    "valueExtractor": "value_extractor",
    "verificationStatus": "verification_status",
    "versionId": "version_id",
    "versionTemplate": "version_template",
    "verticalPodAutoscaling": "vertical_pod_autoscaling",
    "vlanTag8021q": "vlan_tag8021q",
    "vpcAccessCustomEndpoint": "vpc_access_custom_endpoint",
    "vpcConnector": "vpc_connector",
    "vpnGateway": "vpn_gateway",
    "vpnGatewayInterface": "vpn_gateway_interface",
    "vpnInterfaces": "vpn_interfaces",
    "vpnTunnel": "vpn_tunnel",
    "waitForInstances": "wait_for_instances",
    "webBackendService": "web_backend_service",
    "workerConfig": "worker_config",
    "workloadIdentityConfig": "workload_identity_config",
    "writerIdentity": "writer_identity",
}
